```@meta
CurrentModule = Antique
```

# Morse Potential

The Morse potential is a model for inter-nuclear anharmonic vibration in a diatomic molecule.

## Definitions

``\xi := 2\lambda\mathrm{e}^{-a(r-r_e)}``, ``\omega := \sqrt{k/µ}``, ``k := 2D_\mathrm{e}a^2``, ``\lambda := \frac{\sqrt{2mD_\mathrm{e}}}{a\hbar}``, ``\chi := \frac{\hbar\omega}{4D_\mathrm{e}}``, ``N_n := \sqrt{\frac{n!(2\lambda-2n-1)a}{\Gamma(2\lambda-n)}}``, ``L_n^{(\alpha)}(x) := \frac{x^{-\alpha} \mathrm{e}^x}{n !} \frac{\mathrm{d}^n}{\mathrm{d} x^n}\left(\mathrm{e}^{-x} x^{n+\alpha}\right)`` are used. The domains of the potential and the wave functions are $0\leq r \lt \infty$.


#### Schrödinger Equation
```math
  \hat{H}\psi(r) = E \psi(r)
```

#### Hamiltonian
```math
  \hat{H} = - \frac{\hbar^2}{2\mu} \frac{\mathrm{d}^2}{\mathrm{d}r ^2} + V(r)
```

#### Potential
`V(r; rₑ=rₑ, Dₑ=Dₑ, k=k, a=sqrt(k/(2*Dₑ)))`
```math
  V(r) = D_\mathrm{e} \left( \mathrm{e}^{-2a(r-r_e)} - 2\mathrm{e}^{-a(r-r_e)} \right)
```

#### Eigen Values
`E(n; rₑ=rₑ, Dₑ=Dₑ, k=k, a=sqrt(k/(2*Dₑ)), µ=µ, ω=sqrt(k/µ), χ=ℏ*ω/(4*Dₑ), ℏ=ℏ)`
```math
  E_n = - D_\mathrm{e} + \hbar \omega \left( n + \frac{1}{2} \right) - \chi \hbar \omega \left( n + \frac{1}{2} \right)^2
```

#### Eigen Functions
`ψ(n, r; rₑ=rₑ, Dₑ=Dₑ, k=k, a=sqrt(k/(2*Dₑ)), µ=µ, ω=sqrt(k/µ), χ=ℏ*ω/(4*Dₑ), ℏ=ℏ)`
```math
  \psi_n(r) = N_n z^{\lambda-n-1/2} \mathrm{e}^{-z/2} L_n^{(2\lambda-2n-1)}(\xi)
```

#### Generalized Laguerre Polynomials
`L(x; n=0, α=0)`

Rodrigues' formula & closed-form:
```math
  \begin{aligned}
    L_n^{(\alpha)}(x)
    &= \frac{x^{-\alpha}e^x}{n!} \frac{d^n}{dx^n}\left(x^{n+\alpha}e^{-x}\right) \\
    &= \sum_{k=0}^n(-1)^k \left(\begin{array}{l} n+\alpha \\ n-k \end{array}\right) \frac{x^k}{k !} \\
    &= \sum_{k=0}^n(-1)^k \frac{\Gamma(\alpha+n+1)}{\Gamma(\alpha+k+1)\Gamma(n-k+1)} \frac{x^k}{k !}.
  \end{aligned}
```
Examples:
```math
  \begin{aligned}
    L_0^{(0)}(x) &= 1, \\
    L_1^{(0)}(x) &= 1 - x, \\
    L_1^{(1)}(x) &= 2 - x, \\
    L_2^{(0)}(x) &= 1 - 2 x + 1/2 x^{2}, \\
    L_2^{(1)}(x) &= 3 - 3 x + 1/2 x^{2}, \\
    L_2^{(2)}(x) &= 6 - 4 x + 1/2 x^{2}, \\
    L_3^{(0)}(x) &= 1 - 3 x + 3/2 x^{2} - 1/6 x^{3}, \\
    L_3^{(1)}(x) &= 4 - 6 x + 2 x^{2} - 1/6 x^{3}, \\
    L_3^{(2)}(x) &= 10 - 10 x + 5/2 x^{2} - 1/6 x^{3}, \\
    L_3^{(3)}(x) &= 20 - 15 x + 3 x^{2} - 1/6 x^{3}, \\
    L_4^{(0)}(x) &= 1 - 4 x + 3 x^{2} - 2/3 x^{3} + 1/24 x^{4}, \\
    L_4^{(1)}(x) &= 5 - 10 x + 5 x^{2} - 5/6 x^{3} + 1/24 x^{4}, \\
    L_4^{(2)}(x) &= 15 - 20 x + 15/2 x^{2} - 1 x^{3} + 1/24 x^{4}, \\
    L_4^{(3)}(x) &= 35 - 35 x + 21/2 x^{2} - 7/6 x^{3} + 1/24 x^{4}, \\
    L_4^{(4)}(x) &= 70 - 56 x + 14 x^{2} - 4/3 x^{3} + 1/24 x^{4}, \\
    \vdots
  \end{aligned}
```

#### References
- [P. M. Morse, Phys. Rev. 34, 57 (1929)](https://doi.org/10.1103/PhysRev.34.57)
- [J. P. Dahl, M. Springborg, J. Chem. Phys. 88, 4535 (1988). (62), (63)](https://doi.org/10.1063/1.453761)
- [W. K. Shao, Y. He, J. Pan, J. Nonlinear Sci. Appl., 9, 5, 3388 (2016). (1.6)](http://dx.doi.org/10.22436/jnsa.009.05.124) 
- The Digital Library of Mathematical Functions (DLMF) [18.3 Table1](https://dlmf.nist.gov/18.3#T1), [18.5 Table1](https://dlmf.nist.gov/18.5#T1), [18.5.12](https://dlmf.nist.gov/18.5#E12)

## Usage & Examples

[Install Antique.jl](@ref Install) for the first run and run `using Antique` before each use. The function `antique(model, parameters...)` returns a module that has `E()`, `ψ(r)`, `V(r)` and some other functions. In this system, the model name is specified by `:MorsePotential` and several parameters `rₑ`, `Dₑ`, `k`, `µ` and `ℏ` are set as optional arguments.

!!! warning

    Run `using Pkg; Pkg.add("SpecialFunctions")` if the following returns an error.

```julia
# Parameters for H₂⁺
# https://doi.org/10.1002/slct.202102509
# https://doi.org/10.5281/zenodo.5047817
# https://physics.nist.gov/cgi-bin/cuu/Value?mpsme
rₑ =  1.997193319969992120068298141276
Vₑ = -0.602634619106539878727562156289
Dₑ = - 0.5 - Vₑ
k = 2*((-1.1026342144949464615+1/2.00) - Vₑ) / (2.00 - rₑ)^2
µ = 1/(1/1836.15267343 + 1/1836.15267343)
ℏ = 1.0

using Antique
MP = antique(:MorsePotential, rₑ=rₑ, Vₑ=Vₑ, Dₑ=Dₑ, k=k, µ =µ, ℏ =ℏ)
```




Parameters:

```julia
julia> MP.rₑ
1.997193319969992

julia> MP.Dₑ
0.10263461910653993

julia> MP.k
0.1027265041900817

julia> MP.µ
918.076336715

julia> MP.ℏ
1.0
```



Eigen values:

```julia
julia> MP.E(n=0)
-0.09741377794418261

julia> MP.E(n=1)
-0.08738092406760907
```



Potential energy curve:

```julia
using Plots
plot(0.1:0.01:15, r -> MP.V(r), lw=2, label="", xlims=(0.1,9.1), ylims=(-0.11,0.01), xlabel="r", ylabel="V(r)")
```

![](./assets/fig//MorsePotential_4_1.png)



Wave functions:

```julia
using Plots
plot(xlim=(0,5), xlabel="x", ylabel="ψ(x)")
plot!(x -> MP.ψ(x, n=0), label="n=0", lw=2)
plot!(x -> MP.ψ(x, n=1), label="n=1", lw=2)
plot!(x -> MP.ψ(x, n=2), label="n=2", lw=2)
plot!(x -> MP.ψ(x, n=3), label="n=3", lw=2)
plot!(x -> MP.ψ(x, n=4), label="n=4", lw=2)
plot!(x -> MP.ψ(x, n=5), label="n=5", lw=2)
```

![](./assets/fig//MorsePotential_5_1.png)



Potential energy curve, Energy levels, Comparison with harmonic oscillator:

```julia
MP = antique(:MorsePotential)
HO = antique(:HarmonicOscillator, k=MP.k, m=MP.μ)
using Plots
plot(xlims=(0.1,9.1), ylims=(-0.11,0.01), xlabel="\$r\$", ylabel="\$V(r), E_n\$", legend=:bottomright, size=(480,400), dpi=300)
for n in 0:MP.nₘₐₓ()
  # energy
  EM = MP.E(n=n)
  EH = HO.E(n=n) - MP.Dₑ
  plot!(0.1:0.01:15, r -> EH > HO.V(r-MP.rₑ) - MP.Dₑ ? EH : NaN, lc="#BC1C5F", lw=1, label="")
  plot!(0.1:0.01:15, r -> EM > MP.V(r) ? EM : NaN, lc="#578FC7", lw=1, label="")
end
# potential
plot!(0.1:0.01:15, r -> HO.V(r-MP.rₑ) - MP.Dₑ, lc="#BC1C5F", lw=2, label="Harmonic Oscillator")
plot!(0.1:0.01:15, r -> MP.V(r), lc="#578FC7", lw=2, label="Morse Potential")
```

![](./assets/fig//MorsePotential_6_1.png)



where, the potential of harmonic oscillator is defined as $V(r) \simeq \frac{1}{2} k (r - r_\mathrm{e})^2 + V_0$.

## Testing

Unit testing and Integration testing were done using computer algebra system ([Symbolics.jl](https://symbolics.juliasymbolics.org/stable/)) and numerical integration ([QuadGK.jl](https://juliamath.github.io/QuadGK.jl/stable/)). The test script is [here](https://github.com/ohno/Antique.jl/blob/main/test/MorsePotential.jl).

#### Generalized Laguerre Polynomials $L_n^{(\alpha)}(x)$

```math
  \begin{aligned}
    L_n^{(\alpha)}(x)
    &= \frac{x^{-\alpha}e^x}{n!} \frac{d^n}{dx^n}\left(x^{n+\alpha}e^{-x}\right) \\
    &= \sum_{k=0}^n(-1)^k \frac{\Gamma(\alpha+n+1)}{\Gamma(\alpha+k+1)\Gamma(n-k+1)} \frac{x^k}{k !}.
  \end{aligned}
```

``n=0, α=0:`` ✔
```math
\begin{aligned}
  L_{0}^{(0)}(x)
   = e^{x} e^{ - x}
  &= 1 \\
  &= 1
\end{aligned}
```

``n=1, α=0:`` ✔
```math
\begin{aligned}
  L_{1}^{(0)}(x)
   = e^{x} \frac{\mathrm{d}}{\mathrm{d}x} x e^{ - x}
  &= 1 - x \\
  &= 1 - x
\end{aligned}
```

``n=1, α=1:`` ✔
```math
\begin{aligned}
  L_{1}^{(1)}(x)
   = \frac{e^{x} \frac{\mathrm{d}}{\mathrm{d}x} x^{2} e^{ - x}}{x}
  &= 2 - x \\
  &= 2 - x
\end{aligned}
```

``n=2, α=0:`` ✔
```math
\begin{aligned}
  L_{2}^{(0)}(x)
   = \frac{1}{2} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{2} e^{ - x}
  &= 1 - 2 x + \frac{1}{2} x^{2} \\
  &= 1 - 2 x + \frac{1}{2} x^{2}
\end{aligned}
```

``n=2, α=1:`` ✔
```math
\begin{aligned}
  L_{2}^{(1)}(x)
   = \frac{\frac{1}{2} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{3} e^{ - x}}{x}
  &= 3 - 3 x + \frac{1}{2} x^{2} \\
  &= 3 - 3 x + \frac{1}{2} x^{2}
\end{aligned}
```

``n=2, α=2:`` ✔
```math
\begin{aligned}
  L_{2}^{(2)}(x)
   = \frac{\frac{1}{2} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{4} e^{ - x}}{x^{2}}
  &= 6 - 4 x + \frac{1}{2} x^{2} \\
  &= 6 - 4 x + \frac{1}{2} x^{2}
\end{aligned}
```

``n=3, α=0:`` ✔
```math
\begin{aligned}
  L_{3}^{(0)}(x)
   = \frac{1}{6} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{3} e^{ - x}
  &= 1 - \frac{1}{6} x^{3} - 3 x + \frac{3}{2} x^{2} \\
  &= 1 - \frac{1}{6} x^{3} - 3 x + \frac{3}{2} x^{2}
\end{aligned}
```

``n=3, α=1:`` ✔
```math
\begin{aligned}
  L_{3}^{(1)}(x)
   = \frac{\frac{1}{6} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{4} e^{ - x}}{x}
  &= 4 - 6 x - \frac{1}{6} x^{3} + 2 x^{2} \\
  &= 4 - \frac{1}{6} x^{3} - 6 x + 2 x^{2}
\end{aligned}
```

``n=3, α=2:`` ✔
```math
\begin{aligned}
  L_{3}^{(2)}(x)
   = \frac{\frac{1}{6} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{5} e^{ - x}}{x^{2}}
  &= 10 - 10 x - \frac{1}{6} x^{3} + \frac{5}{2} x^{2} \\
  &= 10 - \frac{1}{6} x^{3} - 10 x + \frac{5}{2} x^{2}
\end{aligned}
```

``n=3, α=3:`` ✔
```math
\begin{aligned}
  L_{3}^{(3)}(x)
   = \frac{\frac{1}{6} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{6} e^{ - x}}{x^{3}}
  &= 20 - 15 x - \frac{1}{6} x^{3} + 3 x^{2} \\
  &= 20 - \frac{1}{6} x^{3} - 15 x + 3 x^{2}
\end{aligned}
```

``n=4, α=0:`` ✔
```math
\begin{aligned}
  L_{4}^{(0)}(x)
   = \frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{4} e^{ - x}
  &= 1 - \frac{2}{3} x^{3} - 4 x + 3 x^{2} + \frac{1}{24} x^{4} \\
  &= 1 - \frac{2}{3} x^{3} - 4 x + 3 x^{2} + \frac{1}{24} x^{4}
\end{aligned}
```

``n=4, α=1:`` ✔
```math
\begin{aligned}
  L_{4}^{(1)}(x)
   = \frac{\frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{5} e^{ - x}}{x}
  &= 5 - 10 x - \frac{5}{6} x^{3} + 5 x^{2} + \frac{1}{24} x^{4} \\
  &= 5 - \frac{5}{6} x^{3} - 10 x + 5 x^{2} + \frac{1}{24} x^{4}
\end{aligned}
```

``n=4, α=2:`` ✔
```math
\begin{aligned}
  L_{4}^{(2)}(x)
   = \frac{\frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{6} e^{ - x}}{x^{2}}
  &= 15 - 20 x - x^{3} + \frac{15}{2} x^{2} + \frac{1}{24} x^{4} \\
  &= 15 - x^{3} - 20 x + \frac{15}{2} x^{2} + \frac{1}{24} x^{4}
\end{aligned}
```

``n=4, α=3:`` ✔
```math
\begin{aligned}
  L_{4}^{(3)}(x)
   = \frac{\frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{7} e^{ - x}}{x^{3}}
  &= 35 - 35 x - \frac{7}{6} x^{3} + \frac{21}{2} x^{2} + \frac{1}{24} x^{4} \\
  &= 35 - \frac{7}{6} x^{3} - 35 x + \frac{21}{2} x^{2} + \frac{1}{24} x^{4}
\end{aligned}
```

``n=4, α=4:`` ✔
```math
\begin{aligned}
  L_{4}^{(4)}(x)
   = \frac{\frac{1}{24} e^{x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} \frac{\mathrm{d}}{\mathrm{d}x} x^{8} e^{ - x}}{x^{4}}
  &= 70 - 56 x - \frac{4}{3} x^{3} + 14 x^{2} + \frac{1}{24} x^{4} \\
  &= 70 - \frac{4}{3} x^{3} - 56 x + 14 x^{2} + \frac{1}{24} x^{4}
\end{aligned}
```

```
Test Summary:                      | Pass  Total
Lₙ⁽ᵅ⁾(x) = x⁻ᵅeˣ/n! dⁿ/dxⁿ xⁿ⁺ᵅe⁻ˣ |   15     15
```

#### Normalization & Orthogonality of $L_n^{(\alpha)}(x)$

```math
\int_0^\infty L_i^{(\alpha)}(x) L_j^{(\alpha)}(x) x^\alpha \mathrm{e}^{-x} \mathrm{d}x = \frac{\Gamma(n+\alpha+1)}{n!} \delta_{ij}
```

```
   α |  i |  j |        analytical |         numerical 
---- | -- | -- | ----------------- | ----------------- 
0.01 |  0 |  0 |    0.994325851192 |    0.994325852936 ✔
0.01 |  0 |  1 |    0.000000000000 |    0.000000000000 ✔
0.01 |  0 |  2 |    0.000000000000 |    0.000000000000 ✔
0.01 |  0 |  3 |    0.000000000000 |    0.000000000000 ✔
0.01 |  0 |  4 |    0.000000000000 |    0.000000000000 ✔
0.01 |  0 |  5 |    0.000000000000 |    0.000000000000 ✔
0.01 |  0 |  6 |    0.000000000000 |    0.000000000001 ✔
0.01 |  0 |  7 |    0.000000000000 |    0.000000000001 ✔
0.01 |  0 |  8 |    0.000000000000 |    0.000000000001 ✔
0.01 |  0 |  9 |    0.000000000000 |    0.000000000001 ✔
0.01 |  1 |  0 |    0.000000000000 |    0.000000000000 ✔
0.01 |  1 |  1 |    1.004269109703 |    1.004269111483 ✔
0.01 |  1 |  2 |    0.000000000000 |    0.000000000000 ✔
0.01 |  1 |  3 |    0.000000000000 |    0.000000000000 ✔
0.01 |  1 |  4 |    0.000000000000 |    0.000000000001 ✔
0.01 |  1 |  5 |    0.000000000000 |    0.000000000001 ✔
0.01 |  1 |  6 |    0.000000000000 |    0.000000000002 ✔
0.01 |  1 |  7 |    0.000000000000 |    0.000000000002 ✔
0.01 |  1 |  8 |    0.000000000000 |    0.000000000002 ✔
0.01 |  1 |  9 |    0.000000000000 |    0.000000000003 ✔
0.01 |  2 |  0 |    0.000000000000 |    0.000000000000 ✔
0.01 |  2 |  1 |    0.000000000000 |    0.000000000000 ✔
0.01 |  2 |  2 |    1.009290455252 |    1.009290456144 ✔
0.01 |  2 |  3 |    0.000000000000 |    0.000000000001 ✔
0.01 |  2 |  4 |    0.000000000000 |    0.000000000001 ✔
0.01 |  2 |  5 |    0.000000000000 |    0.000000000003 ✔
0.01 |  2 |  6 |    0.000000000000 |    0.000000000002 ✔
0.01 |  2 |  7 |    0.000000000000 |    0.000000000003 ✔
0.01 |  2 |  8 |    0.000000000000 |    0.000000000003 ✔
0.01 |  2 |  9 |    0.000000000000 |    0.000000000007 ✔
0.01 |  3 |  0 |    0.000000000000 |    0.000000000000 ✔
0.01 |  3 |  1 |    0.000000000000 |    0.000000000000 ✔
0.01 |  3 |  2 |    0.000000000000 |    0.000000000001 ✔
0.01 |  3 |  3 |    1.012654756769 |    1.012654758579 ✔
0.01 |  3 |  4 |    0.000000000000 |    0.000000000003 ✔
0.01 |  3 |  5 |    0.000000000000 |    0.000000000003 ✔
0.01 |  3 |  6 |    0.000000000000 |    0.000000000003 ✔
0.01 |  3 |  7 |    0.000000000000 |    0.000000000007 ✔
0.01 |  3 |  8 |    0.000000000000 |    0.000000000014 ✔
0.01 |  3 |  9 |    0.000000000000 |    0.000000000014 ✔
0.01 |  4 |  0 |    0.000000000000 |    0.000000000000 ✔
0.01 |  4 |  1 |    0.000000000000 |    0.000000000001 ✔
0.01 |  4 |  2 |    0.000000000000 |    0.000000000001 ✔
0.01 |  4 |  3 |    0.000000000000 |    0.000000000003 ✔
0.01 |  4 |  4 |    1.015186393661 |    1.015186394564 ✔
0.01 |  4 |  5 |    0.000000000000 |    0.000000000002 ✔
0.01 |  4 |  6 |    0.000000000000 |    0.000000000007 ✔
0.01 |  4 |  7 |    0.000000000000 |    0.000000000014 ✔
0.01 |  4 |  8 |    0.000000000000 |    0.000000000014 ✔
0.01 |  4 |  9 |    0.000000000000 |    0.000000000014 ✔
0.01 |  5 |  0 |    0.000000000000 |    0.000000000000 ✔
0.01 |  5 |  1 |    0.000000000000 |    0.000000000001 ✔
0.01 |  5 |  2 |    0.000000000000 |    0.000000000003 ✔
0.01 |  5 |  3 |    0.000000000000 |    0.000000000003 ✔
0.01 |  5 |  4 |    0.000000000000 |    0.000000000002 ✔
0.01 |  5 |  5 |    1.017216766449 |    1.017216768275 ✔
0.01 |  5 |  6 |    0.000000000000 |    0.000000000014 ✔
0.01 |  5 |  7 |    0.000000000000 |    0.000000000014 ✔
0.01 |  5 |  8 |    0.000000000000 |    0.000000000014 ✔
0.01 |  5 |  9 |    0.000000000000 |    0.000000000028 ✔
0.01 |  6 |  0 |    0.000000000000 |    0.000000000001 ✔
0.01 |  6 |  1 |    0.000000000000 |    0.000000000002 ✔
0.01 |  6 |  2 |    0.000000000000 |    0.000000000002 ✔
0.01 |  6 |  3 |    0.000000000000 |    0.000000000003 ✔
0.01 |  6 |  4 |    0.000000000000 |    0.000000000007 ✔
0.01 |  6 |  5 |    0.000000000000 |    0.000000000014 ✔
0.01 |  6 |  6 |    1.018912127726 |    1.018912128636 ✔
0.01 |  6 |  7 |    0.000000000000 |    0.000000000014 ✔
0.01 |  6 |  8 |    0.000000000000 |    0.000000000028 ✔
0.01 |  6 |  9 |    0.000000000000 |    0.000000000028 ✔
0.01 |  7 |  0 |    0.000000000000 |    0.000000000001 ✔
0.01 |  7 |  1 |    0.000000000000 |    0.000000000002 ✔
0.01 |  7 |  2 |    0.000000000000 |    0.000000000003 ✔
0.01 |  7 |  3 |    0.000000000000 |    0.000000000007 ✔
0.01 |  7 |  4 |    0.000000000000 |    0.000000000014 ✔
0.01 |  7 |  5 |    0.000000000000 |    0.000000000014 ✔
0.01 |  7 |  6 |    0.000000000000 |    0.000000000014 ✔
0.01 |  7 |  7 |    1.020367716480 |    1.020367717392 ✔
0.01 |  7 |  8 |    0.000000000000 |    0.000000000028 ✔
0.01 |  7 |  9 |    0.000000000000 |    0.000000000028 ✔
0.01 |  8 |  0 |    0.000000000000 |    0.000000000001 ✔
0.01 |  8 |  1 |    0.000000000000 |    0.000000000002 ✔
0.01 |  8 |  2 |    0.000000000000 |    0.000000000003 ✔
0.01 |  8 |  3 |    0.000000000000 |    0.000000000014 ✔
0.01 |  8 |  4 |    0.000000000000 |    0.000000000014 ✔
0.01 |  8 |  5 |    0.000000000000 |    0.000000000014 ✔
0.01 |  8 |  6 |    0.000000000000 |    0.000000000028 ✔
0.01 |  8 |  7 |    0.000000000000 |    0.000000000028 ✔
0.01 |  8 |  8 |    1.021643176126 |    1.021643177967 ✔
0.01 |  8 |  9 |    0.000000000000 |    0.000000000028 ✔
0.01 |  9 |  0 |    0.000000000000 |    0.000000000001 ✔
0.01 |  9 |  1 |    0.000000000000 |    0.000000000003 ✔
0.01 |  9 |  2 |    0.000000000000 |    0.000000000007 ✔
0.01 |  9 |  3 |    0.000000000000 |    0.000000000014 ✔
0.01 |  9 |  4 |    0.000000000000 |    0.000000000014 ✔
0.01 |  9 |  5 |    0.000000000000 |    0.000000000028 ✔
0.01 |  9 |  6 |    0.000000000000 |    0.000000000028 ✔
0.01 |  9 |  7 |    0.000000000000 |    0.000000000028 ✔
0.01 |  9 |  8 |    0.000000000000 |    0.000000000028 ✔
0.01 |  9 |  9 |    1.022778335210 |    1.022778336127 ✔
0.05 |  0 |  0 |    0.973504265563 |    0.973504267703 ✔
0.05 |  0 |  1 |    0.000000000000 |    0.000000000000 ✔
0.05 |  0 |  2 |    0.000000000000 |    0.000000000000 ✔
0.05 |  0 |  3 |    0.000000000000 |    0.000000000000 ✔
0.05 |  0 |  4 |    0.000000000000 |    0.000000000000 ✔
0.05 |  0 |  5 |    0.000000000000 |    0.000000000001 ✔
0.05 |  0 |  6 |    0.000000000000 |    0.000000000001 ✔
0.05 |  0 |  7 |    0.000000000000 |    0.000000000002 ✔
0.05 |  0 |  8 |    0.000000000000 |    0.000000000002 ✔
0.05 |  0 |  9 |    0.000000000000 |    0.000000000002 ✔
0.05 |  1 |  0 |    0.000000000000 |    0.000000000000 ✔
0.05 |  1 |  1 |    1.022179478841 |    1.022179479980 ✔
0.05 |  1 |  2 |    0.000000000000 |    0.000000000000 ✔
0.05 |  1 |  3 |    0.000000000000 |    0.000000000001 ✔
0.05 |  1 |  4 |    0.000000000000 |    0.000000000002 ✔
0.05 |  1 |  5 |    0.000000000000 |    0.000000000002 ✔
0.05 |  1 |  6 |    0.000000000000 |    0.000000000002 ✔
0.05 |  1 |  7 |    0.000000000000 |    0.000000000002 ✔
0.05 |  1 |  8 |    0.000000000000 |    0.000000000004 ✔
0.05 |  1 |  9 |    0.000000000000 |    0.000000000007 ✔
0.05 |  2 |  0 |    0.000000000000 |    0.000000000000 ✔
0.05 |  2 |  1 |    0.000000000000 |    0.000000000000 ✔
0.05 |  2 |  2 |    1.047733965812 |    1.047733966390 ✔
0.05 |  2 |  3 |    0.000000000000 |    0.000000000002 ✔
0.05 |  2 |  4 |    0.000000000000 |    0.000000000002 ✔
0.05 |  2 |  5 |    0.000000000000 |    0.000000000004 ✔
0.05 |  2 |  6 |    0.000000000000 |    0.000000000004 ✔
0.05 |  2 |  7 |    0.000000000000 |    0.000000000008 ✔
0.05 |  2 |  8 |    0.000000000000 |    0.000000000008 ✔
0.05 |  2 |  9 |    0.000000000000 |    0.000000000008 ✔
0.05 |  3 |  0 |    0.000000000000 |    0.000000000000 ✔
0.05 |  3 |  1 |    0.000000000000 |    0.000000000001 ✔
0.05 |  3 |  2 |    0.000000000000 |    0.000000000002 ✔
0.05 |  3 |  3 |    1.065196198575 |    1.065196199813 ✔
0.05 |  3 |  4 |    0.000000000000 |    0.000000000004 ✔
0.05 |  3 |  5 |    0.000000000000 |    0.000000000004 ✔
0.05 |  3 |  6 |    0.000000000000 |    0.000000000008 ✔
0.05 |  3 |  7 |    0.000000000000 |    0.000000000008 ✔
0.05 |  3 |  8 |    0.000000000000 |    0.000000000016 ✔
0.05 |  3 |  9 |    0.000000000000 |    0.000000000015 ✔
0.05 |  4 |  0 |    0.000000000000 |    0.000000000000 ✔
0.05 |  4 |  1 |    0.000000000000 |    0.000000000002 ✔
0.05 |  4 |  2 |    0.000000000000 |    0.000000000002 ✔
0.05 |  4 |  3 |    0.000000000000 |    0.000000000004 ✔
0.05 |  4 |  4 |    1.078511151058 |    1.078511152326 ✔
0.05 |  4 |  5 |    0.000000000000 |    0.000000000008 ✔
0.05 |  4 |  6 |    0.000000000000 |    0.000000000008 ✔
0.05 |  4 |  7 |    0.000000000000 |    0.000000000017 ✔
0.05 |  4 |  8 |    0.000000000000 |    0.000000000017 ✔
0.05 |  4 |  9 |    0.000000000000 |    0.000000000036 ✔
0.05 |  5 |  0 |    0.000000000000 |    0.000000000001 ✔
0.05 |  5 |  1 |    0.000000000000 |    0.000000000002 ✔
0.05 |  5 |  2 |    0.000000000000 |    0.000000000004 ✔
0.05 |  5 |  3 |    0.000000000000 |    0.000000000004 ✔
0.05 |  5 |  4 |    0.000000000000 |    0.000000000008 ✔
0.05 |  5 |  5 |    1.089296262568 |    1.089296263862 ✔
0.05 |  5 |  6 |    0.000000000000 |    0.000000000017 ✔
0.05 |  5 |  7 |    0.000000000000 |    0.000000000034 ✔
0.05 |  5 |  8 |    0.000000000000 |    0.000000000035 ✔
0.05 |  5 |  9 |    0.000000000000 |    0.000000000034 ✔
0.05 |  6 |  0 |    0.000000000000 |    0.000000000001 ✔
0.05 |  6 |  1 |    0.000000000000 |    0.000000000002 ✔
0.05 |  6 |  2 |    0.000000000000 |    0.000000000004 ✔
0.05 |  6 |  3 |    0.000000000000 |    0.000000000008 ✔
0.05 |  6 |  4 |    0.000000000000 |    0.000000000008 ✔
0.05 |  6 |  5 |    0.000000000000 |    0.000000000017 ✔
0.05 |  6 |  6 |    1.098373731423 |    1.098373732739 ✔
0.05 |  6 |  7 |    0.000000000000 |    0.000000000035 ✔
0.05 |  6 |  8 |    0.000000000000 |    0.000000000035 ✔
0.05 |  6 |  9 |    0.000000000000 |    0.000000000035 ✔
0.05 |  7 |  0 |    0.000000000000 |    0.000000000002 ✔
0.05 |  7 |  1 |    0.000000000000 |    0.000000000002 ✔
0.05 |  7 |  2 |    0.000000000000 |    0.000000000008 ✔
0.05 |  7 |  3 |    0.000000000000 |    0.000000000008 ✔
0.05 |  7 |  4 |    0.000000000000 |    0.000000000017 ✔
0.05 |  7 |  5 |    0.000000000000 |    0.000000000034 ✔
0.05 |  7 |  6 |    0.000000000000 |    0.000000000035 ✔
0.05 |  7 |  7 |    1.106219258076 |    1.106219258720 ✔
0.05 |  7 |  8 |    0.000000000000 |    0.000000000035 ✔
0.05 |  7 |  9 |    0.000000000000 |    0.000000000036 ✔
0.05 |  8 |  0 |    0.000000000000 |    0.000000000002 ✔
0.05 |  8 |  1 |    0.000000000000 |    0.000000000004 ✔
0.05 |  8 |  2 |    0.000000000000 |    0.000000000008 ✔
0.05 |  8 |  3 |    0.000000000000 |    0.000000000016 ✔
0.05 |  8 |  4 |    0.000000000000 |    0.000000000017 ✔
0.05 |  8 |  5 |    0.000000000000 |    0.000000000035 ✔
0.05 |  8 |  6 |    0.000000000000 |    0.000000000035 ✔
0.05 |  8 |  7 |    0.000000000000 |    0.000000000035 ✔
0.05 |  8 |  8 |    1.113133128439 |    1.113133129790 ✔
0.05 |  8 |  9 |    0.000000000000 |    0.000000000074 ✔
0.05 |  9 |  0 |    0.000000000000 |    0.000000000002 ✔
0.05 |  9 |  1 |    0.000000000000 |    0.000000000007 ✔
0.05 |  9 |  2 |    0.000000000000 |    0.000000000008 ✔
0.05 |  9 |  3 |    0.000000000000 |    0.000000000015 ✔
0.05 |  9 |  4 |    0.000000000000 |    0.000000000036 ✔
0.05 |  9 |  5 |    0.000000000000 |    0.000000000034 ✔
0.05 |  9 |  6 |    0.000000000000 |    0.000000000035 ✔
0.05 |  9 |  7 |    0.000000000000 |    0.000000000036 ✔
0.05 |  9 |  8 |    0.000000000000 |    0.000000000074 ✔
0.05 |  9 |  9 |    1.119317201375 |    1.119317202034 ✔
0.10 |  0 |  0 |    0.951350769867 |    0.951350771636 ✔
0.10 |  0 |  1 |    0.000000000000 |    0.000000000000 ✔
0.10 |  0 |  2 |    0.000000000000 |    0.000000000000 ✔
0.10 |  0 |  3 |    0.000000000000 |    0.000000000000 ✔
0.10 |  0 |  4 |    0.000000000000 |    0.000000000000 ✔
0.10 |  0 |  5 |    0.000000000000 |    0.000000000001 ✔
0.10 |  0 |  6 |    0.000000000000 |    0.000000000001 ✔
0.10 |  0 |  7 |    0.000000000000 |    0.000000000001 ✔
0.10 |  0 |  8 |    0.000000000000 |    0.000000000001 ✔
0.10 |  0 |  9 |    0.000000000000 |    0.000000000001 ✔
0.10 |  1 |  0 |    0.000000000000 |    0.000000000000 ✔
0.10 |  1 |  1 |    1.046485846854 |    1.046485847852 ✔
0.10 |  1 |  2 |    0.000000000000 |    0.000000000001 ✔
0.10 |  1 |  3 |    0.000000000000 |    0.000000000001 ✔
0.10 |  1 |  4 |    0.000000000000 |    0.000000000001 ✔
0.10 |  1 |  5 |    0.000000000000 |    0.000000000001 ✔
0.10 |  1 |  6 |    0.000000000000 |    0.000000000001 ✔
0.10 |  1 |  7 |    0.000000000000 |    0.000000000003 ✔
0.10 |  1 |  8 |    0.000000000000 |    0.000000000003 ✔
0.10 |  1 |  9 |    0.000000000000 |    0.000000000006 ✔
0.10 |  2 |  0 |    0.000000000000 |    0.000000000000 ✔
0.10 |  2 |  1 |    0.000000000000 |    0.000000000001 ✔
0.10 |  2 |  2 |    1.098810139196 |    1.098810140297 ✔
0.10 |  2 |  3 |    0.000000000000 |    0.000000000001 ✔
0.10 |  2 |  4 |    0.000000000000 |    0.000000000001 ✔
0.10 |  2 |  5 |    0.000000000000 |    0.000000000003 ✔
0.10 |  2 |  6 |    0.000000000000 |    0.000000000003 ✔
0.10 |  2 |  7 |    0.000000000000 |    0.000000000006 ✔
0.10 |  2 |  8 |    0.000000000000 |    0.000000000006 ✔
0.10 |  2 |  9 |    0.000000000000 |    0.000000000006 ✔
0.10 |  3 |  0 |    0.000000000000 |    0.000000000000 ✔
0.10 |  3 |  1 |    0.000000000000 |    0.000000000001 ✔
0.10 |  3 |  2 |    0.000000000000 |    0.000000000001 ✔
0.10 |  3 |  3 |    1.135437143836 |    1.135437145012 ✔
0.10 |  3 |  4 |    0.000000000000 |    0.000000000006 ✔
0.10 |  3 |  5 |    0.000000000000 |    0.000000000003 ✔
0.10 |  3 |  6 |    0.000000000000 |    0.000000000006 ✔
0.10 |  3 |  7 |    0.000000000000 |    0.000000000006 ✔
0.10 |  3 |  8 |    0.000000000000 |    0.000000000013 ✔
0.10 |  3 |  9 |    0.000000000000 |    0.000000000013 ✔
0.10 |  4 |  0 |    0.000000000000 |    0.000000000000 ✔
0.10 |  4 |  1 |    0.000000000000 |    0.000000000001 ✔
0.10 |  4 |  2 |    0.000000000000 |    0.000000000001 ✔
0.10 |  4 |  3 |    0.000000000000 |    0.000000000006 ✔
0.10 |  4 |  4 |    1.163823072432 |    1.163823073667 ✔
0.10 |  4 |  5 |    0.000000000000 |    0.000000000006 ✔
0.10 |  4 |  6 |    0.000000000000 |    0.000000000013 ✔
0.10 |  4 |  7 |    0.000000000000 |    0.000000000013 ✔
0.10 |  4 |  8 |    0.000000000000 |    0.000000000014 ✔
0.10 |  4 |  9 |    0.000000000000 |    0.000000000029 ✔
0.10 |  5 |  0 |    0.000000000000 |    0.000000000001 ✔
0.10 |  5 |  1 |    0.000000000000 |    0.000000000001 ✔
0.10 |  5 |  2 |    0.000000000000 |    0.000000000003 ✔
0.10 |  5 |  3 |    0.000000000000 |    0.000000000003 ✔
0.10 |  5 |  4 |    0.000000000000 |    0.000000000006 ✔
0.10 |  5 |  5 |    1.187099533881 |    1.187099535166 ✔
0.10 |  5 |  6 |    0.000000000000 |    0.000000000013 ✔
0.10 |  5 |  7 |    0.000000000000 |    0.000000000029 ✔
0.10 |  5 |  8 |    0.000000000000 |    0.000000000030 ✔
0.10 |  5 |  9 |    0.000000000000 |    0.000000000030 ✔
0.10 |  6 |  0 |    0.000000000000 |    0.000000000001 ✔
0.10 |  6 |  1 |    0.000000000000 |    0.000000000001 ✔
0.10 |  6 |  2 |    0.000000000000 |    0.000000000003 ✔
0.10 |  6 |  3 |    0.000000000000 |    0.000000000006 ✔
0.10 |  6 |  4 |    0.000000000000 |    0.000000000013 ✔
0.10 |  6 |  5 |    0.000000000000 |    0.000000000013 ✔
0.10 |  6 |  6 |    1.206884526112 |    1.206884527440 ✔
0.10 |  6 |  7 |    0.000000000000 |    0.000000000030 ✔
0.10 |  6 |  8 |    0.000000000000 |    0.000000000030 ✔
0.10 |  6 |  9 |    0.000000000000 |    0.000000000065 ✔
0.10 |  7 |  0 |    0.000000000000 |    0.000000000001 ✔
0.10 |  7 |  1 |    0.000000000000 |    0.000000000003 ✔
0.10 |  7 |  2 |    0.000000000000 |    0.000000000006 ✔
0.10 |  7 |  3 |    0.000000000000 |    0.000000000006 ✔
0.10 |  7 |  4 |    0.000000000000 |    0.000000000013 ✔
0.10 |  7 |  5 |    0.000000000000 |    0.000000000029 ✔
0.10 |  7 |  6 |    0.000000000000 |    0.000000000030 ✔
0.10 |  7 |  7 |    1.224125733628 |    1.224125734265 ✔
0.10 |  7 |  8 |    0.000000000000 |    0.000000000066 ✔
0.10 |  7 |  9 |    0.000000000000 |    0.000000000031 ✔
0.10 |  8 |  0 |    0.000000000000 |    0.000000000001 ✔
0.10 |  8 |  1 |    0.000000000000 |    0.000000000003 ✔
0.10 |  8 |  2 |    0.000000000000 |    0.000000000006 ✔
0.10 |  8 |  3 |    0.000000000000 |    0.000000000013 ✔
0.10 |  8 |  4 |    0.000000000000 |    0.000000000014 ✔
0.10 |  8 |  5 |    0.000000000000 |    0.000000000030 ✔
0.10 |  8 |  6 |    0.000000000000 |    0.000000000030 ✔
0.10 |  8 |  7 |    0.000000000000 |    0.000000000066 ✔
0.10 |  8 |  8 |    1.239427305298 |    1.239427306699 ✔
0.10 |  8 |  9 |    0.000000000000 |    0.000000000067 ✔
0.10 |  9 |  0 |    0.000000000000 |    0.000000000001 ✔
0.10 |  9 |  1 |    0.000000000000 |    0.000000000006 ✔
0.10 |  9 |  2 |    0.000000000000 |    0.000000000006 ✔
0.10 |  9 |  3 |    0.000000000000 |    0.000000000013 ✔
0.10 |  9 |  4 |    0.000000000000 |    0.000000000029 ✔
0.10 |  9 |  5 |    0.000000000000 |    0.000000000030 ✔
0.10 |  9 |  6 |    0.000000000000 |    0.000000000065 ✔
0.10 |  9 |  7 |    0.000000000000 |    0.000000000031 ✔
0.10 |  9 |  8 |    0.000000000000 |    0.000000000067 ✔
0.10 |  9 |  9 |    1.253198719802 |    1.253198721234 ✔
0.50 |  0 |  0 |    0.886226925453 |    0.886226925863 ✔
0.50 |  0 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  0 |  2 |    0.000000000000 |    0.000000000000 ✔
0.50 |  0 |  3 |    0.000000000000 |    0.000000000000 ✔
0.50 |  0 |  4 |    0.000000000000 |    0.000000000000 ✔
0.50 |  0 |  5 |    0.000000000000 |    0.000000000000 ✔
0.50 |  0 |  6 |    0.000000000000 |    0.000000000000 ✔
0.50 |  0 |  7 |    0.000000000000 |    0.000000000000 ✔
0.50 |  0 |  8 |    0.000000000000 |    0.000000000000 ✔
0.50 |  0 |  9 |    0.000000000000 |   -0.000000000000 ✔
0.50 |  1 |  0 |    0.000000000000 |    0.000000000000 ✔
0.50 |  1 |  1 |    1.329340388179 |    1.329340389103 ✔
0.50 |  1 |  2 |    0.000000000000 |    0.000000000000 ✔
0.50 |  1 |  3 |    0.000000000000 |    0.000000000000 ✔
0.50 |  1 |  4 |    0.000000000000 |    0.000000000000 ✔
0.50 |  1 |  5 |    0.000000000000 |    0.000000000000 ✔
0.50 |  1 |  6 |    0.000000000000 |    0.000000000000 ✔
0.50 |  1 |  7 |    0.000000000000 |    0.000000000000 ✔
0.50 |  1 |  8 |    0.000000000000 |    0.000000000000 ✔
0.50 |  1 |  9 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  0 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  2 |    1.661675485224 |    1.661675485734 ✔
0.50 |  2 |  3 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  4 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  5 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  6 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  7 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  8 |    0.000000000000 |    0.000000000000 ✔
0.50 |  2 |  9 |    0.000000000000 |   -0.000000000000 ✔
0.50 |  3 |  0 |    0.000000000000 |    0.000000000000 ✔
0.50 |  3 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  3 |  2 |    0.000000000000 |    0.000000000000 ✔
0.50 |  3 |  3 |    1.938621399428 |    1.938621400123 ✔
0.50 |  3 |  4 |    0.000000000000 |    0.000000000000 ✔
0.50 |  3 |  5 |    0.000000000000 |    0.000000000001 ✔
0.50 |  3 |  6 |    0.000000000000 |    0.000000000001 ✔
0.50 |  3 |  7 |    0.000000000000 |    0.000000000001 ✔
0.50 |  3 |  8 |    0.000000000000 |    0.000000000001 ✔
0.50 |  3 |  9 |    0.000000000000 |    0.000000000001 ✔
0.50 |  4 |  0 |    0.000000000000 |    0.000000000000 ✔
0.50 |  4 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  4 |  2 |    0.000000000000 |    0.000000000000 ✔
0.50 |  4 |  3 |    0.000000000000 |    0.000000000000 ✔
0.50 |  4 |  4 |    2.180949074356 |    2.180949075236 ✔
0.50 |  4 |  5 |    0.000000000000 |    0.000000000001 ✔
0.50 |  4 |  6 |    0.000000000000 |    0.000000000001 ✔
0.50 |  4 |  7 |    0.000000000000 |    0.000000000001 ✔
0.50 |  4 |  8 |    0.000000000000 |    0.000000000001 ✔
0.50 |  4 |  9 |    0.000000000000 |    0.000000000003 ✔
0.50 |  5 |  0 |    0.000000000000 |    0.000000000000 ✔
0.50 |  5 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  5 |  2 |    0.000000000000 |    0.000000000000 ✔
0.50 |  5 |  3 |    0.000000000000 |    0.000000000001 ✔
0.50 |  5 |  4 |    0.000000000000 |    0.000000000001 ✔
0.50 |  5 |  5 |    2.399043981792 |    2.399043982856 ✔
0.50 |  5 |  6 |    0.000000000000 |    0.000000000001 ✔
0.50 |  5 |  7 |    0.000000000000 |    0.000000000001 ✔
0.50 |  5 |  8 |    0.000000000000 |    0.000000000003 ✔
0.50 |  5 |  9 |    0.000000000000 |    0.000000000001 ✔
0.50 |  6 |  0 |    0.000000000000 |    0.000000000000 ✔
0.50 |  6 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  6 |  2 |    0.000000000000 |    0.000000000000 ✔
0.50 |  6 |  3 |    0.000000000000 |    0.000000000001 ✔
0.50 |  6 |  4 |    0.000000000000 |    0.000000000001 ✔
0.50 |  6 |  5 |    0.000000000000 |    0.000000000001 ✔
0.50 |  6 |  6 |    2.598964313608 |    2.598964314050 ✔
0.50 |  6 |  7 |    0.000000000000 |    0.000000000003 ✔
0.50 |  6 |  8 |    0.000000000000 |    0.000000000003 ✔
0.50 |  6 |  9 |    0.000000000000 |    0.000000000008 ✔
0.50 |  7 |  0 |    0.000000000000 |    0.000000000000 ✔
0.50 |  7 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  7 |  2 |    0.000000000000 |    0.000000000000 ✔
0.50 |  7 |  3 |    0.000000000000 |    0.000000000001 ✔
0.50 |  7 |  4 |    0.000000000000 |    0.000000000001 ✔
0.50 |  7 |  5 |    0.000000000000 |    0.000000000001 ✔
0.50 |  7 |  6 |    0.000000000000 |    0.000000000003 ✔
0.50 |  7 |  7 |    2.784604621723 |    2.784604622230 ✔
0.50 |  7 |  8 |    0.000000000000 |    0.000000000008 ✔
0.50 |  7 |  9 |    0.000000000000 |    0.000000000009 ✔
0.50 |  8 |  0 |    0.000000000000 |    0.000000000000 ✔
0.50 |  8 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  8 |  2 |    0.000000000000 |    0.000000000000 ✔
0.50 |  8 |  3 |    0.000000000000 |    0.000000000001 ✔
0.50 |  8 |  4 |    0.000000000000 |    0.000000000001 ✔
0.50 |  8 |  5 |    0.000000000000 |    0.000000000003 ✔
0.50 |  8 |  6 |    0.000000000000 |    0.000000000003 ✔
0.50 |  8 |  7 |    0.000000000000 |    0.000000000008 ✔
0.50 |  8 |  8 |    2.958642410581 |    2.958642412199 ✔
0.50 |  8 |  9 |    0.000000000000 |    0.000000000009 ✔
0.50 |  9 |  0 |    0.000000000000 |   -0.000000000000 ✔
0.50 |  9 |  1 |    0.000000000000 |    0.000000000000 ✔
0.50 |  9 |  2 |    0.000000000000 |   -0.000000000000 ✔
0.50 |  9 |  3 |    0.000000000000 |    0.000000000001 ✔
0.50 |  9 |  4 |    0.000000000000 |    0.000000000003 ✔
0.50 |  9 |  5 |    0.000000000000 |    0.000000000001 ✔
0.50 |  9 |  6 |    0.000000000000 |    0.000000000008 ✔
0.50 |  9 |  7 |    0.000000000000 |    0.000000000009 ✔
0.50 |  9 |  8 |    0.000000000000 |    0.000000000009 ✔
0.50 |  9 |  9 |    3.123011433391 |    3.123011435194 ✔
1.00 |  0 |  0 |    1.000000000000 |    1.000000000000 ✔
1.00 |  0 |  1 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  0 |  2 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  0 |  3 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  0 |  4 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  0 |  5 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  0 |  6 |    0.000000000000 |    0.000000000000 ✔
1.00 |  0 |  7 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  0 |  8 |    0.000000000000 |    0.000000000000 ✔
1.00 |  0 |  9 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  1 |  0 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  1 |  1 |    2.000000000000 |    2.000000000000 ✔
1.00 |  1 |  2 |    0.000000000000 |    0.000000000000 ✔
1.00 |  1 |  3 |    0.000000000000 |    0.000000000000 ✔
1.00 |  1 |  4 |    0.000000000000 |    0.000000000000 ✔
1.00 |  1 |  5 |    0.000000000000 |    0.000000000000 ✔
1.00 |  1 |  6 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  1 |  7 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  1 |  8 |    0.000000000000 |    0.000000000000 ✔
1.00 |  1 |  9 |    0.000000000000 |    0.000000000000 ✔
1.00 |  2 |  0 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  2 |  1 |    0.000000000000 |    0.000000000000 ✔
1.00 |  2 |  2 |    3.000000000000 |    3.000000000000 ✔
1.00 |  2 |  3 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  2 |  4 |    0.000000000000 |    0.000000000000 ✔
1.00 |  2 |  5 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  2 |  6 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  2 |  7 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  2 |  8 |    0.000000000000 |    0.000000000000 ✔
1.00 |  2 |  9 |    0.000000000000 |    0.000000000000 ✔
1.00 |  3 |  0 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  3 |  1 |    0.000000000000 |    0.000000000000 ✔
1.00 |  3 |  2 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  3 |  3 |    4.000000000000 |    4.000000000000 ✔
1.00 |  3 |  4 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  3 |  5 |    0.000000000000 |    0.000000000000 ✔
1.00 |  3 |  6 |    0.000000000000 |    0.000000000000 ✔
1.00 |  3 |  7 |    0.000000000000 |    0.000000000000 ✔
1.00 |  3 |  8 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  3 |  9 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  4 |  0 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  4 |  1 |    0.000000000000 |    0.000000000000 ✔
1.00 |  4 |  2 |    0.000000000000 |    0.000000000000 ✔
1.00 |  4 |  3 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  4 |  4 |    5.000000000000 |    4.999999999999 ✔
1.00 |  4 |  5 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  4 |  6 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  4 |  7 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  4 |  8 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  4 |  9 |    0.000000000000 |    0.000000000000 ✔
1.00 |  5 |  0 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  5 |  1 |    0.000000000000 |    0.000000000000 ✔
1.00 |  5 |  2 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  5 |  3 |    0.000000000000 |    0.000000000000 ✔
1.00 |  5 |  4 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  5 |  5 |    6.000000000000 |    6.000000000000 ✔
1.00 |  5 |  6 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  5 |  7 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  5 |  8 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  5 |  9 |    0.000000000000 |    0.000000000000 ✔
1.00 |  6 |  0 |    0.000000000000 |    0.000000000000 ✔
1.00 |  6 |  1 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  6 |  2 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  6 |  3 |    0.000000000000 |    0.000000000000 ✔
1.00 |  6 |  4 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  6 |  5 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  6 |  6 |    7.000000000000 |    7.000000000000 ✔
1.00 |  6 |  7 |    0.000000000000 |    0.000000000000 ✔
1.00 |  6 |  8 |    0.000000000000 |    0.000000000000 ✔
1.00 |  6 |  9 |    0.000000000000 |    0.000000000000 ✔
1.00 |  7 |  0 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  7 |  1 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  7 |  2 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  7 |  3 |    0.000000000000 |    0.000000000000 ✔
1.00 |  7 |  4 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  7 |  5 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  7 |  6 |    0.000000000000 |    0.000000000000 ✔
1.00 |  7 |  7 |    8.000000000000 |    8.000000000000 ✔
1.00 |  7 |  8 |    0.000000000000 |    0.000000000000 ✔
1.00 |  7 |  9 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  8 |  0 |    0.000000000000 |    0.000000000000 ✔
1.00 |  8 |  1 |    0.000000000000 |    0.000000000000 ✔
1.00 |  8 |  2 |    0.000000000000 |    0.000000000000 ✔
1.00 |  8 |  3 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  8 |  4 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  8 |  5 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  8 |  6 |    0.000000000000 |    0.000000000000 ✔
1.00 |  8 |  7 |    0.000000000000 |    0.000000000000 ✔
1.00 |  8 |  8 |    9.000000000000 |    9.000000000001 ✔
1.00 |  8 |  9 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  9 |  0 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  9 |  1 |    0.000000000000 |    0.000000000000 ✔
1.00 |  9 |  2 |    0.000000000000 |    0.000000000000 ✔
1.00 |  9 |  3 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  9 |  4 |    0.000000000000 |    0.000000000000 ✔
1.00 |  9 |  5 |    0.000000000000 |    0.000000000000 ✔
1.00 |  9 |  6 |    0.000000000000 |    0.000000000000 ✔
1.00 |  9 |  7 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  9 |  8 |    0.000000000000 |   -0.000000000000 ✔
1.00 |  9 |  9 |   10.000000000000 |   10.000000000001 ✔
Test Summary:                                  | Pass  Total
∫Lᵢ⁽ᵅ⁾(x)Lⱼ⁽ᵅ⁾(x)xᵅexp(-x)dx = Γ(i+α+1)/i! δᵢⱼ |  500    500
```

#### Normalization & Orthogonality of $\psi_n(r)$

```math
\int_0^\infty \psi_i^\ast(r) \psi_j(r) \mathrm{d}r = \delta_{ij}
```

```
 i |  j |        analytical |         numerical 
-- | -- | ----------------- | ----------------- 
 0 |  0 |    1.000000000000 |    1.000000000000 ✔
 0 |  1 |    0.000000000000 |    0.000000000000 ✔
 0 |  2 |    0.000000000000 |   -0.000000000000 ✔
 0 |  3 |    0.000000000000 |    0.000000000000 ✔
 0 |  4 |    0.000000000000 |    0.000000000000 ✔
 0 |  5 |    0.000000000000 |   -0.000000000000 ✔
 0 |  6 |    0.000000000000 |   -0.000000000000 ✔
 0 |  7 |    0.000000000000 |    0.000000000002 ✔
 0 |  8 |    0.000000000000 |   -0.000000000026 ✔
 0 |  9 |    0.000000000000 |   -0.000000000104 ✔
 1 |  0 |    0.000000000000 |    0.000000000000 ✔
 1 |  1 |    1.000000000000 |    1.000000000000 ✔
 1 |  2 |    0.000000000000 |   -0.000000000000 ✔
 1 |  3 |    0.000000000000 |    0.000000000000 ✔
 1 |  4 |    0.000000000000 |    0.000000000000 ✔
 1 |  5 |    0.000000000000 |   -0.000000000000 ✔
 1 |  6 |    0.000000000000 |    0.000000000000 ✔
 1 |  7 |    0.000000000000 |    0.000000000001 ✔
 1 |  8 |    0.000000000000 |   -0.000000000022 ✔
 1 |  9 |    0.000000000000 |   -0.000000000067 ✔
 2 |  0 |    0.000000000000 |   -0.000000000000 ✔
 2 |  1 |    0.000000000000 |   -0.000000000000 ✔
 2 |  2 |    1.000000000000 |    1.000000000000 ✔
 2 |  3 |    0.000000000000 |   -0.000000000000 ✔
 2 |  4 |    0.000000000000 |    0.000000000000 ✔
 2 |  5 |    0.000000000000 |   -0.000000000000 ✔
 2 |  6 |    0.000000000000 |    0.000000000000 ✔
 2 |  7 |    0.000000000000 |    0.000000000000 ✔
 2 |  8 |    0.000000000000 |   -0.000000000009 ✔
 2 |  9 |    0.000000000000 |   -0.000000000030 ✔
 3 |  0 |    0.000000000000 |    0.000000000000 ✔
 3 |  1 |    0.000000000000 |    0.000000000000 ✔
 3 |  2 |    0.000000000000 |   -0.000000000000 ✔
 3 |  3 |    1.000000000000 |    1.000000000000 ✔
 3 |  4 |    0.000000000000 |   -0.000000000000 ✔
 3 |  5 |    0.000000000000 |   -0.000000000000 ✔
 3 |  6 |    0.000000000000 |    0.000000000000 ✔
 3 |  7 |    0.000000000000 |   -0.000000000001 ✔
 3 |  8 |    0.000000000000 |   -0.000000000002 ✔
 3 |  9 |    0.000000000000 |   -0.000000000006 ✔
 4 |  0 |    0.000000000000 |    0.000000000000 ✔
 4 |  1 |    0.000000000000 |    0.000000000000 ✔
 4 |  2 |    0.000000000000 |    0.000000000000 ✔
 4 |  3 |    0.000000000000 |   -0.000000000000 ✔
 4 |  4 |    1.000000000000 |    1.000000000000 ✔
 4 |  5 |    0.000000000000 |    0.000000000000 ✔
 4 |  6 |    0.000000000000 |    0.000000000000 ✔
 4 |  7 |    0.000000000000 |    0.000000000000 ✔
 4 |  8 |    0.000000000000 |   -0.000000000001 ✔
 4 |  9 |    0.000000000000 |    0.000000000001 ✔
 5 |  0 |    0.000000000000 |   -0.000000000000 ✔
 5 |  1 |    0.000000000000 |   -0.000000000000 ✔
 5 |  2 |    0.000000000000 |   -0.000000000000 ✔
 5 |  3 |    0.000000000000 |   -0.000000000000 ✔
 5 |  4 |    0.000000000000 |    0.000000000000 ✔
 5 |  5 |    1.000000000000 |    1.000000000000 ✔
 5 |  6 |    0.000000000000 |   -0.000000000000 ✔
 5 |  7 |    0.000000000000 |   -0.000000000001 ✔
 5 |  8 |    0.000000000000 |    0.000000000000 ✔
 5 |  9 |    0.000000000000 |   -0.000000000001 ✔
 6 |  0 |    0.000000000000 |   -0.000000000000 ✔
 6 |  1 |    0.000000000000 |    0.000000000000 ✔
 6 |  2 |    0.000000000000 |    0.000000000000 ✔
 6 |  3 |    0.000000000000 |    0.000000000000 ✔
 6 |  4 |    0.000000000000 |    0.000000000000 ✔
 6 |  5 |    0.000000000000 |   -0.000000000000 ✔
 6 |  6 |    1.000000000000 |    1.000000000000 ✔
 6 |  7 |    0.000000000000 |   -0.000000000000 ✔
 6 |  8 |    0.000000000000 |   -0.000000000002 ✔
 6 |  9 |    0.000000000000 |   -0.000000000003 ✔
 7 |  0 |    0.000000000000 |    0.000000000002 ✔
 7 |  1 |    0.000000000000 |    0.000000000001 ✔
 7 |  2 |    0.000000000000 |    0.000000000000 ✔
 7 |  3 |    0.000000000000 |   -0.000000000001 ✔
 7 |  4 |    0.000000000000 |    0.000000000000 ✔
 7 |  5 |    0.000000000000 |   -0.000000000001 ✔
 7 |  6 |    0.000000000000 |   -0.000000000000 ✔
 7 |  7 |    1.000000000000 |    1.000000000000 ✔
 7 |  8 |    0.000000000000 |   -0.000000000000 ✔
 7 |  9 |    0.000000000000 |    0.000000000004 ✔
 8 |  0 |    0.000000000000 |   -0.000000000026 ✔
 8 |  1 |    0.000000000000 |   -0.000000000022 ✔
 8 |  2 |    0.000000000000 |   -0.000000000009 ✔
 8 |  3 |    0.000000000000 |   -0.000000000002 ✔
 8 |  4 |    0.000000000000 |   -0.000000000001 ✔
 8 |  5 |    0.000000000000 |    0.000000000000 ✔
 8 |  6 |    0.000000000000 |   -0.000000000002 ✔
 8 |  7 |    0.000000000000 |   -0.000000000000 ✔
 8 |  8 |    1.000000000000 |    0.999999999995 ✔
 8 |  9 |    0.000000000000 |    0.000000000000 ✔
 9 |  0 |    0.000000000000 |   -0.000000000104 ✔
 9 |  1 |    0.000000000000 |   -0.000000000067 ✔
 9 |  2 |    0.000000000000 |   -0.000000000030 ✔
 9 |  3 |    0.000000000000 |   -0.000000000006 ✔
 9 |  4 |    0.000000000000 |    0.000000000001 ✔
 9 |  5 |    0.000000000000 |   -0.000000000001 ✔
 9 |  6 |    0.000000000000 |   -0.000000000003 ✔
 9 |  7 |    0.000000000000 |    0.000000000004 ✔
 9 |  8 |    0.000000000000 |    0.000000000000 ✔
 9 |  9 |    1.000000000000 |    1.000000000015 ✔
Test Summary: | Pass  Total
<ψᵢ|ψⱼ> = δᵢⱼ |  100    100
```

#### Eigen Values

```math
  \begin{aligned}
    E_n
    &=      \int \psi^\ast_n(r) \hat{H} \psi_n(r) \mathrm{d}x \\
    &=      \int \psi^\ast_n(r) \left[ \hat{V} + \hat{T} \right] \psi(r) \mathrm{d}x \\
    &=      \int \psi^\ast_n(r) \left[ V(r) - \frac{\hbar^2}{2m} \frac{\mathrm{d}^{2}}{\mathrm{d} r^{2}} \right] \psi(r) \mathrm{d}x \\
    &\simeq \int \psi^\ast_n(r) \left[ V(r)\psi(r) -\frac{\hbar^2}{2m} \frac{\psi(r+\Delta r) - 2\psi(r) + \psi(r-\Delta r)}{\Delta r^{2}} \right] \mathrm{d}x.
  \end{aligned}
```

Where, the difference formula for the 2nd-order derivative:

```math
\begin{aligned}
  % 2\psi(r)
  % + \frac{\mathrm{d}^{2} \psi(r)}{\mathrm{d} r^{2}} \Delta r^{2}
  % + O\left(\Delta r^{4}\right)
  % &=
  % \psi(r+\Delta r)
  % + \psi(r-\Delta r)
  % \\
  % \frac{\mathrm{d}^{2} \psi(r)}{\mathrm{d} r^{2}} \Delta r^{2}
  % &=
  % \psi(r+\Delta r)
  % - 2\psi(r)
  % + \psi(r-\Delta r)
  % - O\left(\Delta r^{4}\right)
  % \\
  % \frac{\mathrm{d}^{2} \psi(r)}{\mathrm{d} r^{2}}
  % &=
  % \frac{\psi(r+\Delta r) - 2\psi(r) + \psi(r-\Delta r)}{\Delta r^{2}}
  % - \frac{O\left(\Delta r^{4}\right)}{\Delta r^{2}}
  % \\
  \frac{\mathrm{d}^{2} \psi(r)}{\mathrm{d} r^{2}}
  &=
  \frac{\psi(r+\Delta r) - 2\psi(r) + \psi(r-\Delta r)}{\Delta r^{2}}
  + O\left(\Delta r^{2}\right)
\end{aligned}
```

are given by the sum of 2 Taylor series:

```math
\begin{aligned}
\psi(r+\Delta r)
&= \psi(r)
+ \frac{\mathrm{d} \psi(r)}{\mathrm{d} r} \Delta r
+ \frac{1}{2!} \frac{\mathrm{d}^{2} \psi(r)}{\mathrm{d} r^{2}} \Delta r^{2}
+ \frac{1}{3!} \frac{\mathrm{d}^{3} \psi(r)}{\mathrm{d} r^{3}} \Delta r^{3}
+ O\left(\Delta r^{4}\right),
\\
\psi(r-\Delta r)
&= \psi(r)
- \frac{\mathrm{d} \psi(r)}{\mathrm{d} r} \Delta r
+ \frac{1}{2!} \frac{\mathrm{d}^{2} \psi(r)}{\mathrm{d} r^{2}} \Delta r^{2}
- \frac{1}{3!} \frac{\mathrm{d}^{3} \psi(r)}{\mathrm{d} r^{3}} \Delta r^{3}
+ O\left(\Delta r^{4}\right).
\end{aligned}
```

```
  k |  n |        analytical |         numerical 
--- | -- | ----------------- | ----------------- 
0.1 |  0 |   -0.097482629904 |   -0.097482629943 ✔
0.1 |  1 |   -0.087576629073 |   -0.087576629208 ✔
0.1 |  2 |   -0.078201265005 |   -0.078201265359 ✔
0.1 |  3 |   -0.069356537702 |   -0.069356538266 ✔
0.1 |  4 |   -0.061042447162 |   -0.061042448777 ✔
0.1 |  5 |   -0.053258993386 |   -0.053258996131 ✔
0.1 |  6 |   -0.046006176374 |   -0.046006177829 ✔
0.1 |  7 |   -0.039283996126 |   -0.039283997743 ✔
0.1 |  8 |   -0.033092452642 |   -0.033092467851 ✔
0.1 |  9 |   -0.027431545922 |   -0.027431467792 ✔
0.2 |  0 |   -0.095387461081 |   -0.095387461144 ✔
0.2 |  1 |   -0.081689100176 |   -0.081689100427 ✔
0.2 |  2 |   -0.069052012799 |   -0.069052013380 ✔
0.2 |  3 |   -0.057476198949 |   -0.057476199867 ✔
0.2 |  4 |   -0.046961658628 |   -0.046961660317 ✔
0.2 |  5 |   -0.037508391834 |   -0.037508393202 ✔
0.2 |  6 |   -0.029116398568 |   -0.029116400340 ✔
0.2 |  7 |   -0.021785678830 |   -0.021785684062 ✔
0.2 |  8 |   -0.015516232619 |   -0.015516237539 ✔
0.2 |  9 |   -0.010308059937 |   -0.010308062755 ✔
0.3 |  0 |   -0.093795214605 |   -0.093795214695 ✔
0.3 |  1 |   -0.077310338322 |   -0.077310338694 ✔
0.3 |  2 |   -0.062417372330 |   -0.062417373167 ✔
0.3 |  3 |   -0.049116316630 |   -0.049116318029 ✔
0.3 |  4 |   -0.037407171221 |   -0.037407173073 ✔
0.3 |  5 |   -0.027289936105 |   -0.027289938027 ✔
0.3 |  6 |   -0.018764611280 |   -0.018764613693 ✔
0.3 |  7 |   -0.011831196747 |   -0.011831198102 ✔
0.3 |  8 |   -0.006489692505 |   -0.006489694275 ✔
0.3 |  9 |   -0.002740098556 |   -0.002740100893 ✔
0.1 |  0 |   -0.097413777944 |   -0.097413777967 ✔
0.1 |  1 |   -0.087380924068 |   -0.087380924205 ✔
0.1 |  2 |   -0.077893174789 |   -0.077893175145 ✔
0.1 |  3 |   -0.068950530107 |   -0.068950530660 ✔
0.1 |  4 |   -0.060552990023 |   -0.060552989095 ✔
0.1 |  5 |   -0.052700554537 |   -0.052700557255 ✔
0.1 |  6 |   -0.045393223648 |   -0.045393222818 ✔
0.1 |  7 |   -0.038630997356 |   -0.038631017157 ✔
0.1 |  8 |   -0.032413875662 |   -0.032413886246 ✔
0.1 |  9 |   -0.026741858566 |   -0.026742018376 ✔
Test Summary:              | Pass  Total
<ψₙ|H|ψₙ> = ∫ψₙ*Hψₙdx = Eₙ |   40     40

```
